@@ -196,26 +196,18 @@ impl Omegga {
     }
 
     /// Sets an object in the store.
-    pub async fn store_set(
-        &self,
-        key: impl Into<String>,
-        value: Value,
-    ) -> Result<(), ResponseError> {
-        self.request("store.set", Some(json!([key.into(), value])))
-            .await
-            .map(|_| ())
+    pub fn store_set(&self, key: impl Into<String>, value: Value) {
+        self.write_notification("store.set", Some(json!([key.into(), value])))
     }
 
     /// Deletes an object from the store.
-    pub async fn store_delete(&self, key: impl Into<String>) -> Result<(), ResponseError> {
-        self.request("store.delete", Some(Value::String(key.into())))
-            .await
-            .map(|_| ())
+    pub async fn store_delete(&self, key: impl Into<String>) {
+        self.write_notification("store.delete", Some(Value::String(key.into())))
     }
 
     /// Wipes the store.
-    pub async fn store_wipe(&self) -> Result<(), ResponseError> {
-        self.request("store.wipe", None).await.map(|_| ())
+    pub fn store_wipe(&self) {
+        self.write_notification("store.wipe", None)
     }
 
     /// Gets a list of keys in the store.
@@ -394,6 +386,26 @@ impl Omegga {
             .map(|_| ())
     }
 
+    /// Get a player.
+    pub async fn get_player(
+        &self,
+        target: impl Into<String>,
+    ) -> Result<Option<Player>, ResponseError> {
+        self.request("player.get", Some(Value::String(target.into())))
+            .await
+            .map(|r| serde_json::from_value::<Player>(r.unwrap_or(Value::Null)).ok())
+    }
+
+    /// Get a player's roles.
+    pub async fn get_player_roles(
+        &self,
+        target: impl Into<String>,
+    ) -> Result<Option<Vec<String>>, ResponseError> {
+        self.request("player.getRoles", Some(Value::String(target.into())))
+            .await
+            .map(|r| serde_json::from_value::<Vec<String>>(r.unwrap_or(Value::Null)).ok())
+    }
+
     /// Get a player's permissions.
     pub async fn get_player_permissions(
         &self,
